Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/pckbport Support more ALPS V2 devices



details:   https://anonhg.NetBSD.org/src/rev/96bba876bbf0
branches:  trunk
changeset: 449670:96bba876bbf0
user:      ryoon <ryoon%NetBSD.org@localhost>
date:      Sat Mar 16 03:27:15 2019 +0000

description:
Support more ALPS V2 devices

* The V2 devices found in Toshiba dynabook satellite B551/D and
  dynabook SS RX1/T8E.

diffstat:

 sys/dev/pckbport/alps.c |  10 ++++++----
 1 files changed, 6 insertions(+), 4 deletions(-)

diffs (31 lines):

diff -r 8f6dd69c0ce6 -r 96bba876bbf0 sys/dev/pckbport/alps.c
--- a/sys/dev/pckbport/alps.c   Fri Mar 15 22:09:21 2019 +0000
+++ b/sys/dev/pckbport/alps.c   Sat Mar 16 03:27:15 2019 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: alps.c,v 1.10 2018/06/19 23:25:59 uwe Exp $ */
+/* $NetBSD: alps.c,v 1.11 2019/03/16 03:27:15 ryoon Exp $ */
 
 /*-
  * Copyright (c) 2017 Ryo ONODERA <ryo%tetera.org@localhost>
@@ -30,7 +30,7 @@
 #include "opt_pms.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: alps.c,v 1.10 2018/06/19 23:25:59 uwe Exp $");
+__KERNEL_RCSID(0, "$NetBSD: alps.c,v 1.11 2019/03/16 03:27:15 ryoon Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -714,8 +714,10 @@
                /* V7 device in Toshiba dynabook R63/PS */
                sc->version = ALPS_PROTO_V7;
        } else if ((e7sig[0] == 0x73) && (e7sig[1] == 0x02) &&
-               (e7sig[2] == 0x14)) {
-               /* V2 device in NEC VJ22MF-7 (VersaPro JVF-7) */
+               ((e7sig[2] == 0x14) || (e7sig[2] == 0x0a))) {
+               /* 0x14: V2 device in NEC VJ22MF-7 (VersaPro JVF-7) */
+               /* 0x0a: V2 devices in Toshiba dynabook satellite B551/D
+                        and dynabook SS RX1 */
                sc->version = ALPS_PROTO_V2;
        }
 



Home | Main Index | Thread Index | Old Index